@@ -15,26 +15,43 @@ def _match_key_value(key: str, value):
     return {'nested': {'path': first_key, 'query': query}} if first_key in NESTED_SEARCHABLE_KEYS else query
 
 
+def _retry_request_error(func, retry_max: int = 5):
+    err = None
+
+    for _ in range(retry_max):
+        try:
+            return func()
+        except json.decoder.JSONDecodeError as e:
+            err = e
+            continue
+
+    raise err
+
+
 def _safe_get_request(url: str):
-    try:
-        headers = {'Content-Type': 'application/json'}
-        access_token = api_access_token()
-        if access_token:
-            headers['X-Access-Token'] = access_token
-        return requests.get(url, headers=headers).json()
-    except requests.exceptions.RequestException:
-        return None
+    def exec():
+        try:
+            headers = {'Content-Type': 'application/json'}
+            access_token = api_access_token()
+            if access_token:
+                headers['X-Access-Token'] = access_token
+            return requests.get(url, headers=headers).json()
+        except requests.exceptions.RequestException:
+            return None
+    return _retry_request_error(exec)
 
 
 def _safe_post_request(url: str, body: dict):
-    try:
-        headers = {'Content-Type': 'application/json'}
-        access_token = api_access_token()
-        if access_token:
-            headers['X-Access-Token'] = access_token
-        return requests.post(url, json.dumps(body), headers=headers).json()
-    except requests.exceptions.RequestException:
-        return None
+    def exec():
+        try:
+            headers = {'Content-Type': 'application/json'}
+            access_token = api_access_token()
+            if access_token:
+                headers['X-Access-Token'] = access_token
+            return requests.post(url, json.dumps(body), headers=headers).json()
+        except requests.exceptions.RequestException:
+            return None
+    return _retry_request_error(exec)
 
 
 def node_type_to_url(node_type: SchemaType):
